Documentation
¶
Overview ¶
Package mdns implements mDNS (multicast DNS)
Index ¶
Constants ¶
const ( // DefaultAddress is the default used by mDNS // and in most cases should be the address that the // net.Conn passed to Server is bound to DefaultAddress = "224.0.0.0:5353" )
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Config ¶
type Config struct {
// QueryInterval controls how often we sends Queries until we
// get a response for the requested name
QueryInterval time.Duration
// LocalNames are the names that we will generate answers for
// when we get questions
LocalNames []string
// LocalAddress will override the published address with the given IP
// when set. Otherwise, the automatically determined address will be used.
LocalAddress net.IP
LoggerFactory logging.LoggerFactory
// IncludeLoopback will include loopback interfaces to be eligble for queries and answers.
IncludeLoopback bool
// Interfaces will override the interfaces used for queries and answers.
Interfaces []net.Interface
}
Config is used to configure a mDNS client or server.
type Conn ¶
type Conn struct {
// contains filtered or unexported fields
}
Conn represents a mDNS Server
Directories
¶
| Path | Synopsis |
|---|---|
|
examples
|
|
|
query
command
This example program showcases the use of the mDNS client by querying a previously published address
|
This example program showcases the use of the mDNS client by querying a previously published address |
|
server
command
This example program showcases the use of the mDNS server by publishing "pion-test.local"
|
This example program showcases the use of the mDNS server by publishing "pion-test.local" |
|
server/publish_ip
command
This example program allows to set an IP that deviates from the automatically determined interface address.
|
This example program allows to set an IP that deviates from the automatically determined interface address. |
Click to show internal directories.
Click to hide internal directories.